drfscaffolding
=========================

Django app which allow create full APIs based on your models defined in your project.


`Doc <https://angellagunas.github.io/drf-scaffolding/>`_.

`Github <https://github.com/angellagunas/drf-scaffolding/>`_.

